``jnrbase``
===========

|modref| is a collection of common utility libraries that are used in the
Python projects that I (JNRowe_) work on.  Feel free to use it — and perhaps
improve it — in your projects!

|modref| is released under the `GPL v3`_ license.

:Git repository:  https://github.com/JNRowe/jnrbase/
:Issue tracker:  https://github.com/JNRowe/jnrbase/issues/
:Contributors:  https://github.com/JNRowe/jnrbase/contributors/

Contents
--------

.. toctree::
   :maxdepth: 2

   background
   getting_started
   faq
   alternatives
   release
   thaw
   jnrbase.1
   upgrading
   dependency_choices
   NEWS
   api/index
   todo

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* :doc:`glossary`

.. _JNRowe: https://github.com/JNRowe
.. _GPL v3: http://www.gnu.org/licenses/
